@@ -43,7 +43,9 @@ def run_ga(current_schedule_list, to_schedule_read, mas_read, disc_select):
     schedule_days = current_schedule[1]
     day_index = current_schedule[3]
     current_schedule = current_schedule[0]
-    to_schedule = to_schedule_read
+    # to_schedule = to_schedule_read
+    to_schedule = to_schedule_read[0]
+    to_schedule_dict = to_schedule_read[1]
     # current_schedule = read_csv()
     # current_schedule = current_schedule[0]
     empty_schedule = copy.deepcopy(current_schedule)
@@ -109,7 +111,7 @@ def run_ga(current_schedule_list, to_schedule_read, mas_read, disc_select):
     print("Time Taken for GA: " + str(t1 - t0) + ' seconds')
 
     # sol_list = [soln, schedule_days]
-    sol_list = [soln, schedule_days, schedule_date]
+    sol_list = [soln, schedule_days, schedule_date, to_schedule_dict]
     thread1 = Thread(target=show_timetable, args=[sol_list])
     thread1.start()
     # thread2 = Thread(target=create_table, args=(soln, schedule_date))
