@@ -45,7 +45,9 @@ def run_sa(current_schedule_list, to_schedule_read, mas_read, disc_select):
     schedule_days = current_schedule[1]
     day_index = current_schedule[3]
     current_schedule = current_schedule[0]
-    to_schedule = to_schedule_read
+    # to_schedule = to_schedule_read
+    to_schedule = to_schedule_read[0]
+    to_schedule_dict = to_schedule_read[1]
     MAS_full = mas_read
     MAS_allowed = MAS_full[disc_select]
 
@@ -94,7 +96,7 @@ def run_sa(current_schedule_list, to_schedule_read, mas_read, disc_select):
     # thread1.start()
     # thread2 = Thread(target=create_table, args=(soln, schedule_date))
     # thread2.start()
-    sol_list = [soln, schedule_days, schedule_date]
+    sol_list = [soln, schedule_days, schedule_date, to_schedule_dict]
     thread1 = Thread(target=show_timetable, args=[sol_list])
     thread1.start()
     print(curr_score)
\ No newline at end of file
