@@ -43,7 +43,9 @@ def run_ts(current_schedule_list, to_schedule_read, mas_read, disc_select):
     schedule_days = current_schedule[1]
     day_index = current_schedule[3]
     current_schedule = current_schedule[0]
-    to_schedule = to_schedule_read
+    # to_schedule = to_schedule_read
+    to_schedule = to_schedule_read[0]
+    to_schedule_dict = to_schedule_read[1]
     MAS_full = mas_read
     MAS_allowed = MAS_full[disc_select]
 
@@ -74,7 +76,7 @@ def run_ts(current_schedule_list, to_schedule_read, mas_read, disc_select):
             # generate all legal swaps
             legal_swaps = fd.all_legal_swaps_subset(soln, to_schedule, MAS_allowed, day_index,
                                                     OT_indexes)  # use a random subsetted neighbour to make program run faster
-            scores = np.array([[9999, 9999, 9999]])
+            scores = np.array([[9999, 9999, 9999]])  # initialize array
             for swaps in legal_swaps:  # bottleneck
                 sc = MO_calculate(sp.swapping(soln, swaps))
                 scores = np.vstack((scores, sc))
@@ -118,7 +120,7 @@ def run_ts(current_schedule_list, to_schedule_read, mas_read, disc_select):
     # thread1.start()
     # thread2 = Thread(target=create_table, args=(soln, schedule_date))
     # thread2.start()
-    sol_list = [soln, schedule_days, schedule_date]
+    sol_list = [soln, schedule_days, schedule_date, to_schedule_dict]
     thread1 = Thread(target=show_timetable, args=[sol_list])
     thread1.start()
 
