@@ -186,133 +186,22 @@ def show_timetable(current_schedule):
                         25: 'URO'
                         }
 
-    proc_codes_breast = {10: 'mastectomy',
-                         11: 'lumpectomy',
-                         12: 'mastopexy',
-                         13: 'biopsy',
-                         14: 'mammoplasty',
-                         15: 'abscess'
-                         }
-
-    proc_codes_nes = {10: 'Circumcision',
-                      11: 'Pyeloplasty',
-                      12: 'Nephrectomy',
-                      13: 'Cystoscopy',
-                      14: 'Meatoplasty',
-                      15: 'Scrotoplasty'
-                      }
-
-    proc_codes_oto = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_clr = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_hpb = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_pls = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_ent = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_suronco = {10: 'hip',
-                          11: 'tail',
-                          12: 'ankle',
-                          13: 'knee',
-                          14: 'leg',
-                          15: 'elbow'
-                          }
-
-    proc_codes_ugi = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_hnn = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_og = {10: 'hip',
-                     11: 'tail',
-                     12: 'ankle',
-                     13: 'knee',
-                     14: 'leg',
-                     15: 'elbow'
-                     }
-
-    proc_codes_hnd = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_oms = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_vas = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_cts = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
-
-    proc_codes_uro = {10: 'hip',
-                      11: 'tail',
-                      12: 'ankle',
-                      13: 'knee',
-                      14: 'leg',
-                      15: 'elbow'
-                      }
+    proc_codes_breast = current_schedule[3]
+    proc_codes_nes = current_schedule[3]
+    proc_codes_oto = current_schedule[3]
+    proc_codes_clr = current_schedule[3]
+    proc_codes_hpb = current_schedule[3]
+    proc_codes_pls = current_schedule[3]
+    proc_codes_ent = current_schedule[3]
+    proc_codes_suronco = current_schedule[3]
+    proc_codes_ugi = current_schedule[3]
+    proc_codes_hnn = current_schedule[3]
+    proc_codes_og = current_schedule[3]
+    proc_codes_hnd = current_schedule[3]
+    proc_codes_oms = current_schedule[3]
+    proc_codes_vas = current_schedule[3]
+    proc_codes_cts = current_schedule[3]
+    proc_codes_uro = current_schedule[3]
 
     proced_name_dict = {10: proc_codes_breast,
                         11: proc_codes_oto,
